@@ -20,6 +20,7 @@ class Currency(enum.Enum):
     NZD: str = "NZD"
     SGD: str = "SGD"
     LKR: str = "LKR"
+    IDR: str = "IDR"
 
 class Environment(enum.Enum):
     PROD: str = "Production"
@@ -36,7 +37,7 @@ class EnumNotFoundException(CustomException):
 
 def get_environment() -> Environment:
     try:
-        if get_environment_variable("ENVIRONMENT") == Environment.PROD:
+        if get_environment_variable("ENVIRONMENT") == Environment.PROD.value:
             return Environment.PROD
         else:
             return Environment.DEV
